Exception: AV::AVError
- Inherits:
-
StandardError
- Object
- StandardError
- AV::AVError
- Defined in:
- lib/leancloud/error.rb
Overview
Base exception class for errors thrown by the Parse client library. AVError will be raised by any network operation if AV.init() has not been called.